==> acondbs-0.3.6-py3-none-any.whl: tests/schema/product/mutation/product_file_path/test_delete_product_file_path.py <==
import pytest
import textwrap


from ....funcs import assert_mutation

HEADERS = {"Authorization": "Bearer token123"}  # octocat


##__________________________________________________________________||
params = [
    pytest.param(
        {
            "query": textwrap.dedent(
                """
                  mutation m {
                    deleteProductFilePath(pathId: 1) { ok }
                  }
                """,
            ),
        },
        {
            "query": textwrap.dedent(
                """
                  {
                    product(productId: 1001 ) {
                      name timePosted producedBy note
                      paths { edges { node { path note product { productId } } } }
                    }
                  }
                """,
            )
        },
        id="deleteProductFilePath",
    ),
]


@pytest.mark.parametrize("data_mutation, data_query", params)
@pytest.mark.asyncio
async def test_schema_success(
    app, snapshot, data_mutation, data_query, mock_request_backup_db
):

    success = True
    await assert_mutation(
        app,
        snapshot,
        data_mutation,
        HEADERS,
        data_query,
        HEADERS,
        mock_request_backup_db,
        success,
    )


##__________________________________________________________________||
params = [
    pytest.param(
        {
            "query": textwrap.dedent(
                """
                  mutation m {
                    deleteProductFilePath(pathId: 15) { ok }
                  }
                """,
            )
        },
        {
            "query": textwrap.dedent(
                """
                  {
                    allProductFilePaths {
                      edges {
                        node {
                          productId
                        }
                      }
                    }
                  }
                """,
            )
        },
        id="deleteProductFilePath-error",
    ),
]


@pytest.mark.parametrize("data_mutation, data_query", params)
@pytest.mark.asyncio
async def test_schema_error(
    app, snapshot, data_mutation, data_query, mock_request_backup_db
):
    success = False
    await assert_mutation(
        app,
        snapshot,
        data_mutation,
        HEADERS,
        data_query,
        HEADERS,
        mock_request_backup_db,
        success,
    )


##__________________________________________________________________||

==> acondbs-0.4.4-py3-none-any.whl: tests/schema/product/mutation/product_file_path/test_delete_product_file_path.py <==
import textwrap

import pytest

from ....funcs import assert_mutation

HEADERS = {"Authorization": "Bearer token123"}  # octocat


params = [
    pytest.param(
        {
            "query": textwrap.dedent(
                """
                  mutation m {
                    deleteProductFilePath(pathId: 1) { ok }
                  }
                """,
            ),
        },
        {
            "query": textwrap.dedent(
                """
                  {
                    product(productId: 1001 ) {
                      name timePosted note
                      paths { edges { node { path note product { productId } } } }
                    }
                  }
                """,
            )
        },
        id="deleteProductFilePath",
    ),
]


@pytest.mark.parametrize("data_mutation, data_query", params)
@pytest.mark.asyncio
async def test_schema_success(
    app, snapshot, data_mutation, data_query, mock_request_backup_db
):
    success = True
    await assert_mutation(
        app,
        snapshot,
        data_mutation,
        HEADERS,
        data_query,
        HEADERS,
        mock_request_backup_db,
        success,
    )


params = [
    pytest.param(
        {
            "query": textwrap.dedent(
                """
                  mutation m {
                    deleteProductFilePath(pathId: 15) { ok }
                  }
                """,
            )
        },
        {
            "query": textwrap.dedent(
                """
                  {
                    allProductFilePaths {
                      edges {
                        node {
                          productId
                        }
                      }
                    }
                  }
                """,
            )
        },
        id="deleteProductFilePath-error",
    ),
]


@pytest.mark.parametrize("data_mutation, data_query", params)
@pytest.mark.asyncio
async def test_schema_error(
    app, snapshot, data_mutation, data_query, mock_request_backup_db
):
    success = False
    await assert_mutation(
        app,
        snapshot,
        data_mutation,
        HEADERS,
        data_query,
        HEADERS,
        mock_request_backup_db,
        success,
    )
